<?php

if (!defined('ABSPATH')) {
    exit;
}

class Paybylink_Gateway extends WC_Payment_Gateway 
{

    private $paymentUrl;

    public $title, $description, $paybylink_id, $paybylink_key;

    public function __construct() 
    {
        $this->id = 'paybylink';
        $this->has_fields = false;
        $this->method_title = __('Paybylink', 'paybylink-woocommerce');
        $this->method_description = __('Płatności poprzez Paybylink.pl', 'paybylink-woocommerce');

        $this->init_form_fields();
        $this->init_settings();

        $this->title = $this->get_option('title');
        $this->description = $this->get_option('description');
        $this->paybylink_id = $this->get_option('paybylink_id');
        $this->paybylink_key = $this->get_option('paybylink_key');

        add_action('woocommerce_update_options_payment_gateways_' . $this->id, array($this, 'process_admin_options'));
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'));
    }

    public function init_form_fields() 
    {
        $this->form_fields = array(
            'enabled' => array(
                'title' => __('Włącz/Wyłącz', 'paybylink-woocommerce'),
                'type' => 'checkbox',
                'label' => __('Włącz płatności Paybylink', 'paybylink-woocommerce'),
                'default' => 'yes'
            ),
            'title' => array(
                'title' => __('Tytuł', 'paybylink-woocommerce'),
                'type' => 'text',
                'default' => __('Paybylink', 'paybylink-woocommerce'),
            ),
            'description' => array(
                'title' => __('Opis', 'paybylink-woocommerce'),
                'type' => 'textarea',
                'default' => __('Zapłać wygodnie przez Paybylink.', 'paybylink-woocommerce'),
            ),
            'paybylink_id' => array(
                'title' => __('Identyfikator Punktu Płatności', 'paybylink-woocommerce'),
                'type' => 'text',
                'description' => __('Wpisz swój klucz API do integracji z Paybylink.', 'paybylink-woocommerce'),
                'default' => '',
            ),
            'paybylink_key' => array(
                'title' => __('Klucz Punktu Płatności', 'paybylink-woocommerce'),
                'type' => 'text',
                'description' => __('Wpisz swój klucz API do integracji z Paybylink.', 'paybylink-woocommerce'),
                'default' => '',
            ),
        );
    }
    
    public function process_payment($order_id)
    {
        $order = wc_get_order($order_id);

        $shopId = $this->paybylink_id;

        $this->control  = 'ORDER_ID|' . $order_id;
        $this->email  = $order->billing_email;
        $this->notifyURL = rest_url('paybylink/v1/ipn');
        $this->returnUrlSuccess = $this->get_return_url($order);
        $price = floatval($order->order_total);

        $data = $this->paybylink_key . '|' . $shopId . '|' . number_format($price, 2, '.', '');
        if($this->control != null && $this->control != '') {
            $data .= '|' . $this -> control;
        }

        if($description != null && $description != '') {
            $data .= '|' . $description;
        }

        if($this->email != null && $this->email != '') {
            $data .= '|' . $this->email;
        }

        if($this->notifyURL != null && $this->notifyURL != '') {
            $data .= '|' . $this->notifyURL;
        }

        if($this->returnUrlSuccess != null && $this->returnUrlSuccess != '') {
            $data .= '|' . $this->returnUrlSuccess;
        }

        $signature = hash('sha256', $data);

        $paybylinkData = array(
            'shopId'            => intval($shopId),
            'price'             => $price,
            'control'           => $this->control,
            'description'       => $description,
            'email'             => $this->email,
            'notifyURL'         => $this->notifyURL,
            'returnUrlSuccess'  => $this->returnUrlSuccess,
            'signature'         => $signature
        );

        $paybylinkData = json_encode($paybylinkData);
        $response = wp_remote_post('https://secure.pbl.pl/api/v1/transfer/generate', array(
            'method'    => 'POST',
            'timeout'   => 90,
            'body'      => $paybylinkData,
            'headers'   => array(
                'Content-Type' => 'application/json;charset=UTF-8' 
            ),
            'sslverify' => false 
        ));
        $response = json_decode($response['body'], true);

        if(isset($response['url'])) {
            $order->add_order_note(__( 'Nowa wpłata Paybylink', 'paybylink-woocommerce'));

            return array(
                'result' => 'success',
                'redirect' => $response['url'] 
            );
        } else {
            $order->add_order_note(__( 'PBL: ' . json_encode($response), 'paybylink-woocommerce'));

            return array(
                'result' => 'success',
                'redirect' => $response['url'] 
            );
        }
    }

    public function check_ipn_response() 
    {
        $handler = new Paybylink_ITN_Handler();
        $handler->process_itn($this->paybylink_key);
    }

    public function enqueue_scripts() 
    {
        wp_enqueue_script('paybylink_payment', plugins_url('../assets/js/paybylink-payment.js', __FILE__), array('jquery'), '1.0', true);
    }

}
