<?php
/*
 * Plugin Name: WooCommerce Paybylink Payment Gateway
 * Description: Integracja WooCommerce z Paybylink.pl, wspierająca bloki koszyka.
 * Version: 1.1.0
 * Author: Szymon Radoliński
 * Text Domain: paybylink-woocommerce
 */

if (!defined('ABSPATH')) {
    exit;
}

if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    add_action('admin_notices', function() {
        echo '<div class="error"><p>' . __('WooCommerce jest wymagane do działania tej wtyczki', 'paybylink-woocommerce') . '</p></div>';
    });
    return;
}

add_action('plugins_loaded', 'paybylink_init_gateway');
function paybylink_init_gateway() {
    require_once plugin_dir_path(__FILE__) . 'includes/class-paybylink-itn-handler.php';
    require_once plugin_dir_path(__FILE__) . 'includes/class-paybylink-gateway.php';

    add_filter('woocommerce_payment_gateways', function($methods) {
        $methods[] = 'Paybylink_Gateway';
        return $methods;
    });
    
    add_action('rest_api_init', function () {
        register_rest_route('paybylink/v1', '/ipn', array(
            'methods' => array('POST', 'GET'),
            'callback' => array(new Paybylink_Gateway(), 'check_ipn_response'),
            'permission_callback' => '__return_true',
        ));
    });
}

add_action('enqueue_block_assets', 'paybylink_enqueue_block_assets');
function paybylink_enqueue_block_assets() {
    if (function_exists('is_checkout') && is_checkout()) {
        wp_enqueue_script(
            'paybylink-blocks-integration',
            plugins_url('assets/js/paybylink-blocks-integration.js', __FILE__),
            array('wc-blocks-registry', 'wp-element', 'wp-i18n', 'wp-hooks'),
            '1.0.0',
            true
        );

        wp_localize_script('paybylink-blocks-integration', 'paybylink_data', array(
            'gateway_id' => 'paybylink',
            'gateway_title' => __('Paybylink', 'paybylink-woocommerce'),
            'api_url' => site_url('/?wc-api=paybylink_callback')
        ));
    }
}